#!/usr/bin/python3

# Content autogenerated. Do not edit.

syscalls_m32r = {
    "_llseek": 140,
    "_newselect": 142,
    "_sysctl": 149,
    "access": 33,
    "acct": 51,
    "add_key": 286,
    "adjtimex": 124,
    "alarm": 27,
    "bdflush": 134,
    "brk": 45,
    "cachectl": 32,
    "capget": 184,
    "capset": 185,
    "chdir": 12,
    "chmod": 15,
    "chown32": 212,
    "chroot": 61,
    "clock_getres": 266,
    "clock_gettime": 265,
    "clock_nanosleep": 267,
    "clock_settime": 264,
    "clone": 120,
    "close": 6,
    "creat": 8,
    "delete_module": 129,
    "dup": 41,
    "dup2": 63,
    "epoll_create": 254,
    "epoll_ctl": 255,
    "epoll_pwait": 319,
    "epoll_wait": 256,
    "eventfd": 323,
    "execve": 11,
    "exit": 1,
    "exit_group": 252,
    "faccessat": 307,
    "fadvise64": 250,
    "fadvise64_64": 272,
    "fallocate": 324,
    "fchdir": 133,
    "fchmod": 94,
    "fchmodat": 306,
    "fchown32": 207,
    "fchownat": 298,
    "fcntl64": 221,
    "fdatasync": 148,
    "fgetxattr": 231,
    "flistxattr": 234,
    "flock": 143,
    "fork": 2,
    "fremovexattr": 237,
    "fsetxattr": 228,
    "fstat": 108,
    "fstat64": 197,
    "fstatat64": 300,
    "fstatfs": 100,
    "fstatfs64": 269,
    "fsync": 118,
    "ftruncate": 93,
    "ftruncate64": 194,
    "futex": 240,
    "futimesat": 299,
    "get_mempolicy": 275,
    "get_robust_list": 312,
    "get_thread_area": 244,
    "getcpu": 318,
    "getcwd": 183,
    "getdents": 141,
    "getdents64": 220,
    "getegid32": 202,
    "geteuid32": 201,
    "getgid32": 200,
    "getgroups32": 205,
    "getitimer": 105,
    "getpgid": 132,
    "getpgrp": 65,
    "getpid": 20,
    "getppid": 64,
    "getpriority": 96,
    "getresgid32": 211,
    "getresuid32": 209,
    "getrusage": 77,
    "getsid": 147,
    "gettid": 224,
    "gettimeofday": 78,
    "getuid32": 199,
    "getxattr": 229,
    "init_module": 128,
    "inotify_add_watch": 292,
    "inotify_init": 291,
    "inotify_rm_watch": 293,
    "io_cancel": 249,
    "io_destroy": 246,
    "io_getevents": 247,
    "io_setup": 245,
    "io_submit": 248,
    "ioctl": 54,
    "ioprio_get": 290,
    "ioprio_set": 289,
    "ipc": 117,
    "kexec_load": 283,
    "keyctl": 288,
    "kill": 37,
    "lchown32": 198,
    "lgetxattr": 230,
    "link": 9,
    "linkat": 303,
    "listxattr": 232,
    "llistxattr": 233,
    "lookup_dcookie": 253,
    "lremovexattr": 236,
    "lseek": 19,
    "lsetxattr": 227,
    "lstat": 107,
    "lstat64": 196,
    "madvise": 219,
    "mbind": 274,
    "migrate_pages": 294,
    "mincore": 218,
    "mkdir": 39,
    "mkdirat": 296,
    "mknod": 14,
    "mknodat": 297,
    "mlock": 150,
    "mlockall": 152,
    "mmap2": 192,
    "mount": 21,
    "move_pages": 317,
    "mprotect": 125,
    "mq_getsetattr": 282,
    "mq_notify": 281,
    "mq_open": 277,
    "mq_timedreceive": 280,
    "mq_timedsend": 279,
    "mq_unlink": 278,
    "mremap": 163,
    "msync": 144,
    "munlock": 151,
    "munlockall": 153,
    "munmap": 91,
    "nanosleep": 162,
    "nfsservctl": 169,
    "open": 5,
    "openat": 295,
    "pause": 29,
    "personality": 136,
    "pipe": 42,
    "pivot_root": 217,
    "poll": 168,
    "ppoll": 309,
    "prctl": 172,
    "pread64": 180,
    "pselect6": 308,
    "ptrace": 26,
    "pwrite64": 181,
    "quotactl": 131,
    "read": 3,
    "readahead": 225,
    "readlink": 85,
    "readlinkat": 305,
    "readv": 145,
    "reboot": 88,
    "remap_file_pages": 257,
    "removexattr": 235,
    "rename": 38,
    "renameat": 302,
    "request_key": 287,
    "restart_syscall": 0,
    "rmdir": 40,
    "rt_sigaction": 174,
    "rt_sigpending": 176,
    "rt_sigprocmask": 175,
    "rt_sigqueueinfo": 178,
    "rt_sigreturn": 173,
    "rt_sigsuspend": 179,
    "rt_sigtimedwait": 177,
    "sched_get_priority_max": 159,
    "sched_get_priority_min": 160,
    "sched_getaffinity": 242,
    "sched_getparam": 155,
    "sched_getscheduler": 157,
    "sched_rr_get_interval": 161,
    "sched_setaffinity": 241,
    "sched_setparam": 154,
    "sched_setscheduler": 156,
    "sched_yield": 158,
    "sendfile": 187,
    "sendfile64": 239,
    "set_mempolicy": 276,
    "set_robust_list": 311,
    "set_thread_area": 243,
    "set_tid_address": 258,
    "setdomainname": 121,
    "setfsgid32": 216,
    "setfsuid32": 215,
    "setgid32": 214,
    "setgroups32": 206,
    "sethostname": 74,
    "setitimer": 104,
    "setns": 325,
    "setpgid": 57,
    "setpriority": 97,
    "setregid32": 204,
    "setresgid32": 210,
    "setresuid32": 208,
    "setreuid32": 203,
    "setrlimit": 75,
    "setsid": 66,
    "settimeofday": 79,
    "setuid32": 213,
    "setxattr": 226,
    "sigaltstack": 186,
    "signalfd": 321,
    "socketcall": 102,
    "splice": 313,
    "stat": 106,
    "stat64": 195,
    "statfs": 99,
    "statfs64": 268,
    "stime": 25,
    "swapoff": 115,
    "swapon": 87,
    "symlink": 83,
    "symlinkat": 304,
    "sync": 36,
    "sync_file_range": 314,
    "sysfs": 135,
    "sysinfo": 116,
    "syslog": 103,
    "tas": 166,
    "tee": 315,
    "tgkill": 270,
    "time": 13,
    "timer_create": 259,
    "timer_delete": 263,
    "timer_getoverrun": 262,
    "timer_gettime": 261,
    "timer_settime": 260,
    "times": 43,
    "tkill": 238,
    "truncate": 92,
    "truncate64": 193,
    "ugetrlimit": 191,
    "umask": 60,
    "umount": 22,
    "umount2": 52,
    "uname": 122,
    "unlink": 10,
    "unlinkat": 301,
    "unshare": 310,
    "uselib": 86,
    "ustat": 62,
    "utime": 30,
    "utimensat": 320,
    "utimes": 271,
    "vfork": 190,
    "vhangup": 111,
    "vmsplice": 316,
    "vserver": 273,
    "wait4": 114,
    "waitid": 284,
    "waitpid": 7,
    "write": 4,
    "writev": 146,
}
